# AlternateModeSetting


## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**learning_mode** | [**LearningModeSpec**](LearningModeSpec.md) |  | [optional] 
**diagnostic_mode** | **bool** | If enabled the launcher will run in diagnostic mode. It will keep a terminal window open and set the log level to debug.  | [optional] 
**any string name** | **bool, date, datetime, dict, float, int, list, str, none_type** | any string name can be used but the value must be the correct type | [optional]

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


